import { createSignal, createEffect, on, onCleanup } from 'solid-js';

// src/index.ts
var createPermission = (name) => {
  const [permission, setPermission] = createSignal("unknown");
  const [status, setStatus] = createSignal();
  if (navigator) {
    navigator.permissions.query(typeof name === "string" ? { name } : name).then(setStatus).catch((error) => {
      if (error.name !== "TypeError" || name !== "microphone" && name !== "camera") {
        return;
      }
      setPermission("prompt");
      const constraint = name === "camera" ? "video" : "audio";
      const getUserMedia = navigator.mediaDevices.getUserMedia.bind(navigator.mediaDevices);
      navigator.mediaDevices.getUserMedia = (constraints) => constraints?.[constraint] ? getUserMedia(constraints).then((stream) => (setPermission("granted"), stream)).catch((error2) => {
        if (/not allowed/.test(error2.message)) {
          setPermission("denied");
        }
        return Promise.reject(error2);
      }) : getUserMedia(constraints);
    });
    createEffect(
      on(status, (status2) => {
        if (status2) {
          setPermission(status2.state);
          const listener = () => setPermission(status2.state);
          status2.addEventListener("change", listener);
          onCleanup(() => status2.removeEventListener("change", listener));
        }
      })
    );
  }
  return permission;
};

export { createPermission };
